/*******************************************************************************
* File Name: DELAY2A_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "DELAY2A.h"

static DELAY2A_backupStruct DELAY2A_backup;


/*******************************************************************************
* Function Name: DELAY2A_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY2A_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void DELAY2A_SaveConfig(void) 
{

    #if(!DELAY2A_UsingFixedFunction)
        #if(!DELAY2A_PWMModeIsCenterAligned)
            DELAY2A_backup.PWMPeriod = DELAY2A_ReadPeriod();
        #endif /* (!DELAY2A_PWMModeIsCenterAligned) */
        DELAY2A_backup.PWMUdb = DELAY2A_ReadCounter();
        #if (DELAY2A_UseStatus)
            DELAY2A_backup.InterruptMaskValue = DELAY2A_STATUS_MASK;
        #endif /* (DELAY2A_UseStatus) */

        #if(DELAY2A_DeadBandMode == DELAY2A__B_PWM__DBM_256_CLOCKS || \
            DELAY2A_DeadBandMode == DELAY2A__B_PWM__DBM_2_4_CLOCKS)
            DELAY2A_backup.PWMdeadBandValue = DELAY2A_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(DELAY2A_KillModeMinTime)
             DELAY2A_backup.PWMKillCounterPeriod = DELAY2A_ReadKillTime();
        #endif /* (DELAY2A_KillModeMinTime) */

        #if(DELAY2A_UseControl)
            DELAY2A_backup.PWMControlRegister = DELAY2A_ReadControlRegister();
        #endif /* (DELAY2A_UseControl) */
    #endif  /* (!DELAY2A_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: DELAY2A_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY2A_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void DELAY2A_RestoreConfig(void) 
{
        #if(!DELAY2A_UsingFixedFunction)
            #if(!DELAY2A_PWMModeIsCenterAligned)
                DELAY2A_WritePeriod(DELAY2A_backup.PWMPeriod);
            #endif /* (!DELAY2A_PWMModeIsCenterAligned) */

            DELAY2A_WriteCounter(DELAY2A_backup.PWMUdb);

            #if (DELAY2A_UseStatus)
                DELAY2A_STATUS_MASK = DELAY2A_backup.InterruptMaskValue;
            #endif /* (DELAY2A_UseStatus) */

            #if(DELAY2A_DeadBandMode == DELAY2A__B_PWM__DBM_256_CLOCKS || \
                DELAY2A_DeadBandMode == DELAY2A__B_PWM__DBM_2_4_CLOCKS)
                DELAY2A_WriteDeadTime(DELAY2A_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(DELAY2A_KillModeMinTime)
                DELAY2A_WriteKillTime(DELAY2A_backup.PWMKillCounterPeriod);
            #endif /* (DELAY2A_KillModeMinTime) */

            #if(DELAY2A_UseControl)
                DELAY2A_WriteControlRegister(DELAY2A_backup.PWMControlRegister);
            #endif /* (DELAY2A_UseControl) */
        #endif  /* (!DELAY2A_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: DELAY2A_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY2A_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void DELAY2A_Sleep(void) 
{
    #if(DELAY2A_UseControl)
        if(DELAY2A_CTRL_ENABLE == (DELAY2A_CONTROL & DELAY2A_CTRL_ENABLE))
        {
            /*Component is enabled */
            DELAY2A_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            DELAY2A_backup.PWMEnableState = 0u;
        }
    #endif /* (DELAY2A_UseControl) */

    /* Stop component */
    DELAY2A_Stop();

    /* Save registers configuration */
    DELAY2A_SaveConfig();
}


/*******************************************************************************
* Function Name: DELAY2A_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY2A_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void DELAY2A_Wakeup(void) 
{
     /* Restore registers values */
    DELAY2A_RestoreConfig();

    if(DELAY2A_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        DELAY2A_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
