/*******************************************************************************
* File Name: DELAY2B_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "DELAY2B.h"

static DELAY2B_backupStruct DELAY2B_backup;


/*******************************************************************************
* Function Name: DELAY2B_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY2B_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void DELAY2B_SaveConfig(void) 
{

    #if(!DELAY2B_UsingFixedFunction)
        #if(!DELAY2B_PWMModeIsCenterAligned)
            DELAY2B_backup.PWMPeriod = DELAY2B_ReadPeriod();
        #endif /* (!DELAY2B_PWMModeIsCenterAligned) */
        DELAY2B_backup.PWMUdb = DELAY2B_ReadCounter();
        #if (DELAY2B_UseStatus)
            DELAY2B_backup.InterruptMaskValue = DELAY2B_STATUS_MASK;
        #endif /* (DELAY2B_UseStatus) */

        #if(DELAY2B_DeadBandMode == DELAY2B__B_PWM__DBM_256_CLOCKS || \
            DELAY2B_DeadBandMode == DELAY2B__B_PWM__DBM_2_4_CLOCKS)
            DELAY2B_backup.PWMdeadBandValue = DELAY2B_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(DELAY2B_KillModeMinTime)
             DELAY2B_backup.PWMKillCounterPeriod = DELAY2B_ReadKillTime();
        #endif /* (DELAY2B_KillModeMinTime) */

        #if(DELAY2B_UseControl)
            DELAY2B_backup.PWMControlRegister = DELAY2B_ReadControlRegister();
        #endif /* (DELAY2B_UseControl) */
    #endif  /* (!DELAY2B_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: DELAY2B_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY2B_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void DELAY2B_RestoreConfig(void) 
{
        #if(!DELAY2B_UsingFixedFunction)
            #if(!DELAY2B_PWMModeIsCenterAligned)
                DELAY2B_WritePeriod(DELAY2B_backup.PWMPeriod);
            #endif /* (!DELAY2B_PWMModeIsCenterAligned) */

            DELAY2B_WriteCounter(DELAY2B_backup.PWMUdb);

            #if (DELAY2B_UseStatus)
                DELAY2B_STATUS_MASK = DELAY2B_backup.InterruptMaskValue;
            #endif /* (DELAY2B_UseStatus) */

            #if(DELAY2B_DeadBandMode == DELAY2B__B_PWM__DBM_256_CLOCKS || \
                DELAY2B_DeadBandMode == DELAY2B__B_PWM__DBM_2_4_CLOCKS)
                DELAY2B_WriteDeadTime(DELAY2B_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(DELAY2B_KillModeMinTime)
                DELAY2B_WriteKillTime(DELAY2B_backup.PWMKillCounterPeriod);
            #endif /* (DELAY2B_KillModeMinTime) */

            #if(DELAY2B_UseControl)
                DELAY2B_WriteControlRegister(DELAY2B_backup.PWMControlRegister);
            #endif /* (DELAY2B_UseControl) */
        #endif  /* (!DELAY2B_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: DELAY2B_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY2B_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void DELAY2B_Sleep(void) 
{
    #if(DELAY2B_UseControl)
        if(DELAY2B_CTRL_ENABLE == (DELAY2B_CONTROL & DELAY2B_CTRL_ENABLE))
        {
            /*Component is enabled */
            DELAY2B_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            DELAY2B_backup.PWMEnableState = 0u;
        }
    #endif /* (DELAY2B_UseControl) */

    /* Stop component */
    DELAY2B_Stop();

    /* Save registers configuration */
    DELAY2B_SaveConfig();
}


/*******************************************************************************
* Function Name: DELAY2B_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY2B_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void DELAY2B_Wakeup(void) 
{
     /* Restore registers values */
    DELAY2B_RestoreConfig();

    if(DELAY2B_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        DELAY2B_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
