/*******************************************************************************
* File Name: PSFB_1_internal_pwm.c  
* Version 2.40
*
* Description:
*  The PWM User Module consist of an 8 or 16-bit counter with two 8 or 16-bit
*  comparitors. Each instance of this user module is capable of generating
*  two PWM outputs with the same period. The pulse width is selectable between
*  1 and 255/65535. The period is selectable between 2 and 255/65536 clocks. 
*  The compare value output may be configured to be active when the present 
*  counter is less than or less than/equal to the compare value.
*  A terminal count output is also provided. It generates a pulse one clock
*  width wide when the counter is equal to zero.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "PSFB_1_internal_pwm.h"

uint8 PSFB_1_internal_pwm_initVar = 0u;


/*******************************************************************************
* Function Name: PSFB_1_internal_pwm_Start
********************************************************************************
*
* Summary:
*  The start function initializes the pwm with the default values, the 
*  enables the counter to begin counting.  It does not enable interrupts,
*  the EnableInt command should be called if interrupt generation is required.
*
* Parameters:  
*  None  
*
* Return: 
*  None
*
* Global variables:
*  PSFB_1_internal_pwm_initVar: Is modified when this function is called for the 
*   first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void PSFB_1_internal_pwm_Start(void) 
{
    /* If not Initialized then initialize all required hardware and software */
    if(PSFB_1_internal_pwm_initVar == 0u)
    {
        PSFB_1_internal_pwm_Init();
        PSFB_1_internal_pwm_initVar = 1u;
    }
    PSFB_1_internal_pwm_Enable();

}


/*******************************************************************************
* Function Name: PSFB_1_internal_pwm_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  PSFB_1_internal_pwm_Start().
*
* Parameters:  
*  None
*
* Return: 
*  None
*
*******************************************************************************/
void PSFB_1_internal_pwm_Init(void) 
{
    #if (PSFB_1_internal_pwm_UsingFixedFunction || PSFB_1_internal_pwm_UseControl)
        uint8 ctrl;
    #endif /* (PSFB_1_internal_pwm_UsingFixedFunction || PSFB_1_internal_pwm_UseControl) */
    
    #if(!PSFB_1_internal_pwm_UsingFixedFunction) 
        #if(PSFB_1_internal_pwm_UseStatus)
            /* Interrupt State Backup for Critical Region*/
            uint8 PSFB_1_internal_pwm_interruptState;
        #endif /* (PSFB_1_internal_pwm_UseStatus) */
    #endif /* (!PSFB_1_internal_pwm_UsingFixedFunction) */
    
    #if (PSFB_1_internal_pwm_UsingFixedFunction)
        /* You are allowed to write the compare value (FF only) */
        PSFB_1_internal_pwm_CONTROL |= PSFB_1_internal_pwm_CFG0_MODE;
        #if (PSFB_1_internal_pwm_DeadBand2_4)
            PSFB_1_internal_pwm_CONTROL |= PSFB_1_internal_pwm_CFG0_DB;
        #endif /* (PSFB_1_internal_pwm_DeadBand2_4) */
                
        /* Set the default Compare Mode */
        #if(CY_PSOC5A)
                ctrl = PSFB_1_internal_pwm_CONTROL2 & ((uint8)(~PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK));
                PSFB_1_internal_pwm_CONTROL2 = ctrl | PSFB_1_internal_pwm_DEFAULT_COMPARE1_MODE;
        #endif /* (CY_PSOC5A) */
        #if(CY_PSOC3 || CY_PSOC5LP)
                ctrl = PSFB_1_internal_pwm_CONTROL3 & ((uint8 )(~PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK));
                PSFB_1_internal_pwm_CONTROL3 = ctrl | PSFB_1_internal_pwm_DEFAULT_COMPARE1_MODE;
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
        
         /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
        PSFB_1_internal_pwm_RT1 &= ((uint8)(~PSFB_1_internal_pwm_RT1_MASK));
        PSFB_1_internal_pwm_RT1 |= PSFB_1_internal_pwm_SYNC;     
                
        /*Enable DSI Sync all all inputs of the PWM*/
        PSFB_1_internal_pwm_RT1 &= ((uint8)(~PSFB_1_internal_pwm_SYNCDSI_MASK));
        PSFB_1_internal_pwm_RT1 |= PSFB_1_internal_pwm_SYNCDSI_EN;
       
    #elif (PSFB_1_internal_pwm_UseControl)
        /* Set the default compare mode defined in the parameter */
        ctrl = PSFB_1_internal_pwm_CONTROL & ((uint8)(~PSFB_1_internal_pwm_CTRL_CMPMODE2_MASK)) & ((uint8)(~PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK));
        PSFB_1_internal_pwm_CONTROL = ctrl | PSFB_1_internal_pwm_DEFAULT_COMPARE2_MODE | 
                                   PSFB_1_internal_pwm_DEFAULT_COMPARE1_MODE;
    #endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
        
    #if (!PSFB_1_internal_pwm_UsingFixedFunction)
        #if (PSFB_1_internal_pwm_Resolution == 8)
            /* Set FIFO 0 to 1 byte register for period*/
            PSFB_1_internal_pwm_AUX_CONTROLDP0 |= (PSFB_1_internal_pwm_AUX_CTRL_FIFO0_CLR);
        #else /* (PSFB_1_internal_pwm_Resolution == 16)*/
            /* Set FIFO 0 to 1 byte register for period */
            PSFB_1_internal_pwm_AUX_CONTROLDP0 |= (PSFB_1_internal_pwm_AUX_CTRL_FIFO0_CLR);
            PSFB_1_internal_pwm_AUX_CONTROLDP1 |= (PSFB_1_internal_pwm_AUX_CTRL_FIFO0_CLR);
        #endif /* (PSFB_1_internal_pwm_Resolution == 8) */

        PSFB_1_internal_pwm_WriteCounter(PSFB_1_internal_pwm_INIT_PERIOD_VALUE);
    #endif /* (!PSFB_1_internal_pwm_UsingFixedFunction) */
        
    PSFB_1_internal_pwm_WritePeriod(PSFB_1_internal_pwm_INIT_PERIOD_VALUE);

        #if (PSFB_1_internal_pwm_UseOneCompareMode)
            PSFB_1_internal_pwm_WriteCompare(PSFB_1_internal_pwm_INIT_COMPARE_VALUE1);
        #else
            PSFB_1_internal_pwm_WriteCompare1(PSFB_1_internal_pwm_INIT_COMPARE_VALUE1);
            PSFB_1_internal_pwm_WriteCompare2(PSFB_1_internal_pwm_INIT_COMPARE_VALUE2);
        #endif /* (PSFB_1_internal_pwm_UseOneCompareMode) */
        
        #if (PSFB_1_internal_pwm_KillModeMinTime)
            PSFB_1_internal_pwm_WriteKillTime(PSFB_1_internal_pwm_MinimumKillTime);
        #endif /* (PSFB_1_internal_pwm_KillModeMinTime) */
        
        #if (PSFB_1_internal_pwm_DeadBandUsed)
            PSFB_1_internal_pwm_WriteDeadTime(PSFB_1_internal_pwm_INIT_DEAD_TIME);
        #endif /* (PSFB_1_internal_pwm_DeadBandUsed) */

    #if (PSFB_1_internal_pwm_UseStatus || PSFB_1_internal_pwm_UsingFixedFunction)
        PSFB_1_internal_pwm_SetInterruptMode(PSFB_1_internal_pwm_INIT_INTERRUPTS_MODE);
    #endif /* (PSFB_1_internal_pwm_UseStatus || PSFB_1_internal_pwm_UsingFixedFunction) */
        
    #if (PSFB_1_internal_pwm_UsingFixedFunction)
        /* Globally Enable the Fixed Function Block chosen */
        PSFB_1_internal_pwm_GLOBAL_ENABLE |= PSFB_1_internal_pwm_BLOCK_EN_MASK;
        /* Set the Interrupt source to come from the status register */
        PSFB_1_internal_pwm_CONTROL2 |= PSFB_1_internal_pwm_CTRL2_IRQ_SEL;
    #else
        #if(PSFB_1_internal_pwm_UseStatus)
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            PSFB_1_internal_pwm_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            PSFB_1_internal_pwm_STATUS_AUX_CTRL |= PSFB_1_internal_pwm_STATUS_ACTL_INT_EN_MASK;
            
             /* Exit Critical Region*/
            CyExitCriticalSection(PSFB_1_internal_pwm_interruptState);
            
            /* Clear the FIFO to enable the PSFB_1_internal_pwm_STATUS_FIFOFULL
                   bit to be set on FIFO full. */
            PSFB_1_internal_pwm_ClearFIFO();
        #endif /* (PSFB_1_internal_pwm_UseStatus) */
    #endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PSFB_1_internal_pwm_Enable
********************************************************************************
*
* Summary: 
*  Enables the PWM block operation
*
* Parameters:  
*  None
*
* Return: 
*  None
*
* Side Effects: 
*  This works only if software enable mode is chosen
*
*******************************************************************************/
void PSFB_1_internal_pwm_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (PSFB_1_internal_pwm_UsingFixedFunction)
        PSFB_1_internal_pwm_GLOBAL_ENABLE |= PSFB_1_internal_pwm_BLOCK_EN_MASK;
        PSFB_1_internal_pwm_GLOBAL_STBY_ENABLE |= PSFB_1_internal_pwm_BLOCK_STBY_EN_MASK;
    #endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
    
    /* Enable the PWM from the control register  */
    #if (PSFB_1_internal_pwm_UseControl || PSFB_1_internal_pwm_UsingFixedFunction)
        PSFB_1_internal_pwm_CONTROL |= PSFB_1_internal_pwm_CTRL_ENABLE;
    #endif /* (PSFB_1_internal_pwm_UseControl || PSFB_1_internal_pwm_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PSFB_1_internal_pwm_Stop
********************************************************************************
*
* Summary:
*  The stop function halts the PWM, but does not change any modes or disable
*  interrupts.
*
* Parameters:  
*  None  
*
* Return: 
*  None
*
* Side Effects:
*  If the Enable mode is set to Hardware only then this function
*  has no effect on the operation of the PWM
*
*******************************************************************************/
void PSFB_1_internal_pwm_Stop(void) 
{
    #if (PSFB_1_internal_pwm_UseControl || PSFB_1_internal_pwm_UsingFixedFunction)
        PSFB_1_internal_pwm_CONTROL &= ((uint8)(~PSFB_1_internal_pwm_CTRL_ENABLE));
    #endif /* (PSFB_1_internal_pwm_UseControl || PSFB_1_internal_pwm_UsingFixedFunction) */
    
    /* Globally disable the Fixed Function Block chosen */
    #if (PSFB_1_internal_pwm_UsingFixedFunction)
        PSFB_1_internal_pwm_GLOBAL_ENABLE &= ((uint8)(~PSFB_1_internal_pwm_BLOCK_EN_MASK));
        PSFB_1_internal_pwm_GLOBAL_STBY_ENABLE &= ((uint8)(~PSFB_1_internal_pwm_BLOCK_STBY_EN_MASK));
    #endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
}


#if (PSFB_1_internal_pwm_UseOneCompareMode)
	#if (PSFB_1_internal_pwm_CompareMode1SW)


		/*******************************************************************************
		* Function Name: PSFB_1_internal_pwm_SetCompareMode
		********************************************************************************
		* 
		* Summary:
		*  This function writes the Compare Mode for the pwm output when in Dither mode,
		*  Center Align Mode or One Output Mode.
		*
		* Parameters:
		*  comparemode:  The new compare mode for the PWM output. Use the compare types
		*                defined in the H file as input arguments.
		*
		* Return:
		*  None
		*
		*******************************************************************************/
		void PSFB_1_internal_pwm_SetCompareMode(uint8 comparemode) 
		{
		    #if(PSFB_1_internal_pwm_UsingFixedFunction)
            
                #if(0 != PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT)
                    uint8 comparemodemasked = ((uint8)((uint8)comparemode << PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT));
                #else
                    uint8 comparemodemasked = comparemode;
                #endif /* (0 != PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT) */
            
		        #if(CY_PSOC5A)
		            PSFB_1_internal_pwm_CONTROL2 &= ((uint8)(~PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK)); /*Clear Existing Data */
		            PSFB_1_internal_pwm_CONTROL2 |= comparemodemasked;  
		        #endif /* (CY_PSOC5A) */
		                
		        #if(CY_PSOC3 || CY_PSOC5LP)
		            PSFB_1_internal_pwm_CONTROL3 &= ((uint8)(~PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK)); /*Clear Existing Data */
		            PSFB_1_internal_pwm_CONTROL3 |= comparemodemasked;     
		        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
		                
		    #elif (PSFB_1_internal_pwm_UseControl)
		        
                #if(0 != PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT)
                    uint8 comparemode1masked = ((uint8)((uint8)comparemode << PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT)) & 
    		                                    PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK;
                #else
                    uint8 comparemode1masked = comparemode & PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK;                
                #endif /* (0 != PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT) */
                
                #if(0 != PSFB_1_internal_pwm_CTRL_CMPMODE2_SHIFT)                            
    		        uint8 comparemode2masked = ((uint8)((uint8)comparemode << PSFB_1_internal_pwm_CTRL_CMPMODE2_SHIFT)) & 
    		                                   PSFB_1_internal_pwm_CTRL_CMPMODE2_MASK;
                #else
    		        uint8 comparemode2masked = comparemode & PSFB_1_internal_pwm_CTRL_CMPMODE2_MASK;                
                #endif /* (0 != PSFB_1_internal_pwm_CTRL_CMPMODE2_SHIFT) */
                
		        /*Clear existing mode */
		        PSFB_1_internal_pwm_CONTROL &= ((uint8)(~(PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK | PSFB_1_internal_pwm_CTRL_CMPMODE2_MASK))); 
		        PSFB_1_internal_pwm_CONTROL |= (comparemode1masked | comparemode2masked);
		        
		    #else
		        uint8 temp = comparemode;
		    #endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
		}
	#endif /* PSFB_1_internal_pwm_CompareMode1SW */

#else /* UseOneCompareMode */

	#if (PSFB_1_internal_pwm_CompareMode1SW)


		/*******************************************************************************
		* Function Name: PSFB_1_internal_pwm_SetCompareMode1
		********************************************************************************
		* 
		* Summary:
		*  This function writes the Compare Mode for the pwm or pwm1 output
		*
		* Parameters:  
		*  comparemode:  The new compare mode for the PWM output. Use the compare types
		*                defined in the H file as input arguments.
		*
		* Return: 
		*  None
		*
		*******************************************************************************/
		void PSFB_1_internal_pwm_SetCompareMode1(uint8 comparemode) 
		{
		    #if(0 != PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT)
                uint8 comparemodemasked = ((uint8)((uint8)comparemode << PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT)) & 
    		                               PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK;
		    #else
                uint8 comparemodemasked = comparemode & PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK;                
            #endif /* (0 != PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT) */
                   
		    #if (PSFB_1_internal_pwm_UseControl)
		        PSFB_1_internal_pwm_CONTROL &= ((uint8)(~PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK)); /*Clear existing mode */
		        PSFB_1_internal_pwm_CONTROL |= comparemodemasked;
		    #endif /* (PSFB_1_internal_pwm_UseControl) */
		}
	#endif /* PSFB_1_internal_pwm_CompareMode1SW */

#if (PSFB_1_internal_pwm_CompareMode2SW)


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_SetCompareMode2
    ********************************************************************************
    * 
    * Summary:
    *  This function writes the Compare Mode for the pwm or pwm2 output
    *
    * Parameters:  
    *  comparemode:  The new compare mode for the PWM output. Use the compare types
    *                defined in the H file as input arguments.
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void PSFB_1_internal_pwm_SetCompareMode2(uint8 comparemode) 
    {

        #if(0 != PSFB_1_internal_pwm_CTRL_CMPMODE2_SHIFT)
            uint8 comparemodemasked = ((uint8)((uint8)comparemode << PSFB_1_internal_pwm_CTRL_CMPMODE2_SHIFT)) & 
                                                 PSFB_1_internal_pwm_CTRL_CMPMODE2_MASK;
        #else
            uint8 comparemodemasked = comparemode & PSFB_1_internal_pwm_CTRL_CMPMODE2_MASK;            
        #endif /* (0 != PSFB_1_internal_pwm_CTRL_CMPMODE2_SHIFT) */
        
        #if (PSFB_1_internal_pwm_UseControl)
            PSFB_1_internal_pwm_CONTROL &= ((uint8)(~PSFB_1_internal_pwm_CTRL_CMPMODE2_MASK)); /*Clear existing mode */
            PSFB_1_internal_pwm_CONTROL |= comparemodemasked;
        #endif /* (PSFB_1_internal_pwm_UseControl) */
    }
    #endif /*PSFB_1_internal_pwm_CompareMode2SW */

#endif /* UseOneCompareMode */


#if (!PSFB_1_internal_pwm_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_WriteCounter
    ********************************************************************************
    * 
    * Summary:
    *  This function is used to change the counter value.
    *
    * Parameters:  
    *  counter:  This value may be between 1 and (2^Resolution)-1.   
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void PSFB_1_internal_pwm_WriteCounter(uint8 counter) \
                                       
    {
        CY_SET_REG8(PSFB_1_internal_pwm_COUNTER_LSB_PTR, counter);
    }


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_ReadCounter
    ********************************************************************************
    * 
    * Summary:
    *  This function returns the current value of the counter.  It doesn't matter
    *  if the counter is enabled or running.
    *
    * Parameters:  
    *  None  
    *
    * Return: 
    *  The current value of the counter.
    *
    *******************************************************************************/
    uint8 PSFB_1_internal_pwm_ReadCounter(void) 
    {
        /* Force capture by reading Accumulator */
        /* Must first do a software capture to be able to read the counter */
        /* It is up to the user code to make sure there isn't already captured data in the FIFO */
        (void)PSFB_1_internal_pwm_COUNTERCAP_LSB;
        
        /* Read the data from the FIFO (or capture register for Fixed Function)*/
        return (CY_GET_REG8(PSFB_1_internal_pwm_CAPTURE_LSB_PTR));
    }

        #if (PSFB_1_internal_pwm_UseStatus)


            /*******************************************************************************
            * Function Name: PSFB_1_internal_pwm_ClearFIFO
            ********************************************************************************
            * 
            * Summary:
            *  This function clears all capture data from the capture FIFO
            *
            * Parameters:  
            *  None
            *
            * Return: 
            *  None
            *
            *******************************************************************************/
            void PSFB_1_internal_pwm_ClearFIFO(void) 
            {
                while(0u != (PSFB_1_internal_pwm_ReadStatusRegister() & PSFB_1_internal_pwm_STATUS_FIFONEMPTY))
                {
                    (void)PSFB_1_internal_pwm_ReadCapture();
                }
            }

        #endif /* PSFB_1_internal_pwm_UseStatus */

#endif /* !PSFB_1_internal_pwm_UsingFixedFunction */


/*******************************************************************************
* Function Name: PSFB_1_internal_pwm_WritePeriod
********************************************************************************
* 
* Summary:
*  This function is used to change the period of the counter.  The new period 
*  will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period:  Period value. May be between 1 and (2^Resolution)-1.  A value of 0 
*           will result in the counter remaining at zero.
*
* Return: 
*  None
*
*******************************************************************************/
void PSFB_1_internal_pwm_WritePeriod(uint8 period) 
{
    #if(PSFB_1_internal_pwm_UsingFixedFunction)
        CY_SET_REG16(PSFB_1_internal_pwm_PERIOD_LSB_PTR, (uint16)period);
    #else
        CY_SET_REG8(PSFB_1_internal_pwm_PERIOD_LSB_PTR, period);
    #endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
}

#if (PSFB_1_internal_pwm_UseOneCompareMode)


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_WriteCompare
    ********************************************************************************
    * 
    * Summary:
    *  This funtion is used to change the compare1 value when the PWM is in Dither
    *  mode. The compare output will reflect the new value on the next UDB clock. 
    *  The compare output will be driven high when the present counter value is 
    *  compared to the compare value based on the compare mode defined in 
    *  Dither Mode.
    *
    * Parameters:  
    *  compare:  New compare value.  
    *
    * Return: 
    *  None
    *
    * Side Effects:
    *  This function is only available if the PWM mode parameter is set to
    *  Dither Mode, Center Aligned Mode or One Output Mode
    *
    *******************************************************************************/
    void PSFB_1_internal_pwm_WriteCompare(uint8 compare) \
                                       
    {	
		#if(PSFB_1_internal_pwm_UsingFixedFunction)
			CY_SET_REG16(PSFB_1_internal_pwm_COMPARE1_LSB_PTR, (uint16)compare);
		#else
	        CY_SET_REG8(PSFB_1_internal_pwm_COMPARE1_LSB_PTR, compare);	
		#endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
        
        #if (PSFB_1_internal_pwm_PWMMode == PSFB_1_internal_pwm__B_PWM__DITHER)
            #if(PSFB_1_internal_pwm_UsingFixedFunction)
    			CY_SET_REG16(PSFB_1_internal_pwm_COMPARE2_LSB_PTR, (uint16)(compare + 1u));
    		#else
    	        CY_SET_REG8(PSFB_1_internal_pwm_COMPARE2_LSB_PTR, (compare + 1u));	
    		#endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
        #endif /* (PSFB_1_internal_pwm_PWMMode == PSFB_1_internal_pwm__B_PWM__DITHER) */
    }


#else


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_WriteCompare1
    ********************************************************************************
    * 
    * Summary:
    *  This funtion is used to change the compare1 value.  The compare output will 
    *  reflect the new value on the next UDB clock.  The compare output will be 
    *  driven high when the present counter value is less than or less than or 
    *  equal to the compare register, depending on the mode.
    *
    * Parameters:  
    *  compare:  New compare value.  
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void PSFB_1_internal_pwm_WriteCompare1(uint8 compare) \
                                        
    {
        #if(PSFB_1_internal_pwm_UsingFixedFunction)
            CY_SET_REG16(PSFB_1_internal_pwm_COMPARE1_LSB_PTR, (uint16)compare);
        #else
            CY_SET_REG8(PSFB_1_internal_pwm_COMPARE1_LSB_PTR, compare);
        #endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
    }


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_WriteCompare2
    ********************************************************************************
    * 
    * Summary:
    *  This funtion is used to change the compare value, for compare1 output.  
    *  The compare output will reflect the new value on the next UDB clock.  
    *  The compare output will be driven high when the present counter value is 
    *  less than or less than or equal to the compare register, depending on the 
    *  mode.
    *
    * Parameters:  
    *  compare:  New compare value.  
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void PSFB_1_internal_pwm_WriteCompare2(uint8 compare) \
                                        
    {
        #if(PSFB_1_internal_pwm_UsingFixedFunction)
            CY_SET_REG16(PSFB_1_internal_pwm_COMPARE2_LSB_PTR, compare);
        #else
            CY_SET_REG8(PSFB_1_internal_pwm_COMPARE2_LSB_PTR, compare);
        #endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
    }
#endif /* UseOneCompareMode */

#if (PSFB_1_internal_pwm_DeadBandUsed)


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_WriteDeadTime
    ********************************************************************************
    * 
    * Summary:
    *  This function writes the dead-band counts to the corresponding register
    *
    * Parameters:  
    *  deadtime:  Number of counts for dead time 
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void PSFB_1_internal_pwm_WriteDeadTime(uint8 deadtime) 
    {
        /* If using the Dead Band 1-255 mode then just write the register */
        #if(!PSFB_1_internal_pwm_DeadBand2_4)
            CY_SET_REG8(PSFB_1_internal_pwm_DEADBAND_COUNT_PTR, deadtime);
        #else
            /* Otherwise the data has to be masked and offset */        
            /* Clear existing data */
            PSFB_1_internal_pwm_DEADBAND_COUNT &= ((uint8)(~PSFB_1_internal_pwm_DEADBAND_COUNT_MASK));
            
            /* Set new dead time */
            #if(PSFB_1_internal_pwm_DEADBAND_COUNT_SHIFT)        
                PSFB_1_internal_pwm_DEADBAND_COUNT |= ((uint8)((uint8)deadtime << PSFB_1_internal_pwm_DEADBAND_COUNT_SHIFT)) & 
                                                    PSFB_1_internal_pwm_DEADBAND_COUNT_MASK;
            #else
                PSFB_1_internal_pwm_DEADBAND_COUNT |= deadtime & PSFB_1_internal_pwm_DEADBAND_COUNT_MASK;        
            #endif /* (PSFB_1_internal_pwm_DEADBAND_COUNT_SHIFT) */
        
        #endif /* (!PSFB_1_internal_pwm_DeadBand2_4) */
    }


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_ReadDeadTime
    ********************************************************************************
    * 
    * Summary:
    *  This function reads the dead-band counts from the corresponding register
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  Dead Band Counts
    *
    *******************************************************************************/
    uint8 PSFB_1_internal_pwm_ReadDeadTime(void) 
    {
        /* If using the Dead Band 1-255 mode then just read the register */
        #if(!PSFB_1_internal_pwm_DeadBand2_4)
            return (CY_GET_REG8(PSFB_1_internal_pwm_DEADBAND_COUNT_PTR));
        #else
        
            /* Otherwise the data has to be masked and offset */
            #if(PSFB_1_internal_pwm_DEADBAND_COUNT_SHIFT)      
                return ((uint8)(((uint8)(PSFB_1_internal_pwm_DEADBAND_COUNT & PSFB_1_internal_pwm_DEADBAND_COUNT_MASK)) >> 
                                                                           PSFB_1_internal_pwm_DEADBAND_COUNT_SHIFT));
            #else
                return (PSFB_1_internal_pwm_DEADBAND_COUNT & PSFB_1_internal_pwm_DEADBAND_COUNT_MASK);
            #endif /* (PSFB_1_internal_pwm_DEADBAND_COUNT_SHIFT) */
        #endif /* (!PSFB_1_internal_pwm_DeadBand2_4) */
    }
#endif /* DeadBandUsed */

#if (PSFB_1_internal_pwm_UseStatus || PSFB_1_internal_pwm_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_SetInterruptMode
    ********************************************************************************
    * 
    * Summary:
    *  This function configures the interrupts mask control of theinterrupt 
    *  source status register.
    *
    * Parameters:  
    *  uint8 interruptMode: Bit field containing the interrupt sources enabled 
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void PSFB_1_internal_pwm_SetInterruptMode(uint8 interruptMode)  
    {
    	CY_SET_REG8(PSFB_1_internal_pwm_STATUS_MASK_PTR, interruptMode);
    }


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_ReadStatusRegister
    ********************************************************************************
    * 
    * Summary:
    *  This function returns the current state of the status register. 
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8 : Current status register value. The status register bits are:
    *  [7:6] : Unused(0)
    *  [5]   : Kill event output
    *  [4]   : FIFO not empty
    *  [3]   : FIFO full
    *  [2]   : Terminal count
    *  [1]   : Compare output 2
    *  [0]   : Compare output 1
    *
    *******************************************************************************/
    uint8 PSFB_1_internal_pwm_ReadStatusRegister(void)   
    {
    	uint8 result;
    	
    	result = CY_GET_REG8(PSFB_1_internal_pwm_STATUS_PTR);
    	return (result);
    }

#endif /* (PSFB_1_internal_pwm_UseStatus || PSFB_1_internal_pwm_UsingFixedFunction) */


#if (PSFB_1_internal_pwm_UseControl)


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_ReadControlRegister
    ********************************************************************************
    * 
    * Summary:
    *  Returns the current state of the control register. This API is available 
    *  only if the control register is not removed.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  uint8 : Current control register value
    *
    *******************************************************************************/    
    uint8 PSFB_1_internal_pwm_ReadControlRegister(void) 
    {
    	uint8 result;
    	
    	result = CY_GET_REG8(PSFB_1_internal_pwm_CONTROL_PTR);
    	return (result);
    }


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_WriteControlRegister
    ********************************************************************************
    * 
    * Summary:
    *  Sets the bit field of the control register. This API is available only if 
    *  the control register is not removed.
    *
    * Parameters:  
    *  uint8 control: Control register bit field, The status register bits are:
    *  [7]   : PWM Enable
    *  [6]   : Reset
    *  [5:3] : Compare Mode2
    *  [2:0] : Compare Mode2
    *
    * Return: 
    *  None
    *
    *******************************************************************************/  
    void PSFB_1_internal_pwm_WriteControlRegister(uint8 control) 
    {
    	CY_SET_REG8(PSFB_1_internal_pwm_CONTROL_PTR, control);
    }
	
#endif /* (PSFB_1_internal_pwm_UseControl) */


#if (!PSFB_1_internal_pwm_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_ReadCapture
    ********************************************************************************
    * 
    * Summary:
    *  Reads the capture value from the capture FIFO.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: The current capture value
    *
    *******************************************************************************/  
    uint8 PSFB_1_internal_pwm_ReadCapture(void)  
    {
    	return (CY_GET_REG8(PSFB_1_internal_pwm_CAPTURE_LSB_PTR));
    }
	
#endif /* (!PSFB_1_internal_pwm_UsingFixedFunction) */


#if (PSFB_1_internal_pwm_UseOneCompareMode)


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_ReadCompare
    ********************************************************************************
    * 
    * Summary:
    *  Reads the compare value for the compare output when the PWM Mode parameter is 
    *  set to Dither mode, Center Aligned mode, or One Output mode.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: Current compare value
    *
    *******************************************************************************/  
    uint8 PSFB_1_internal_pwm_ReadCompare(void)  
    {
		#if(PSFB_1_internal_pwm_UsingFixedFunction)
            return ((uint8)CY_GET_REG16(PSFB_1_internal_pwm_COMPARE1_LSB_PTR));
        #else
            return (CY_GET_REG8(PSFB_1_internal_pwm_COMPARE1_LSB_PTR));
        #endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
    }

#else


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_ReadCompare1
    ********************************************************************************
    * 
    * Summary:
    *  Reads the compare value for the compare1 output.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: Current compare value.
    *
    *******************************************************************************/  
    uint8 PSFB_1_internal_pwm_ReadCompare1(void) 
    {
		return (CY_GET_REG8(PSFB_1_internal_pwm_COMPARE1_LSB_PTR));
    }


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_ReadCompare2
    ********************************************************************************
    * 
    * Summary:
    *  Reads the compare value for the compare2 output.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: Current compare value.
    *
    *******************************************************************************/  
    uint8 PSFB_1_internal_pwm_ReadCompare2(void)  
    {
		return (CY_GET_REG8(PSFB_1_internal_pwm_COMPARE2_LSB_PTR));
    }

#endif /* (PSFB_1_internal_pwm_UseOneCompareMode) */


/*******************************************************************************
* Function Name: PSFB_1_internal_pwm_ReadPeriod
********************************************************************************
* 
* Summary:
*  Reads the period value used by the PWM hardware.
*
* Parameters:  
*  None
*
* Return: 
*  uint8/16: Period value
*
*******************************************************************************/ 
uint8 PSFB_1_internal_pwm_ReadPeriod(void) 
{
	#if(PSFB_1_internal_pwm_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(PSFB_1_internal_pwm_PERIOD_LSB_PTR));
    #else
        return (CY_GET_REG8(PSFB_1_internal_pwm_PERIOD_LSB_PTR));
    #endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
}

#if ( PSFB_1_internal_pwm_KillModeMinTime)


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_WriteKillTime
    ********************************************************************************
    * 
    * Summary:
    *  Writes the kill time value used by the hardware when the Kill Mode 
    *  is set to Minimum Time.
    *
    * Parameters:  
    *  uint8: Minimum Time kill counts
    *
    * Return: 
    *  None
    *
    *******************************************************************************/ 
    void PSFB_1_internal_pwm_WriteKillTime(uint8 killtime) 
    {
    	CY_SET_REG8(PSFB_1_internal_pwm_KILLMODEMINTIME_PTR, killtime);
    }


    /*******************************************************************************
    * Function Name: PSFB_1_internal_pwm_ReadKillTime
    ********************************************************************************
    * 
    * Summary:
    *  Reads the kill time value used by the hardware when the Kill Mode is set 
    *  to Minimum Time.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8: The current Minimum Time kill counts
    *
    *******************************************************************************/ 
    uint8 PSFB_1_internal_pwm_ReadKillTime(void) 
    {
    	return (CY_GET_REG8(PSFB_1_internal_pwm_KILLMODEMINTIME_PTR));
    }

#endif /* ( PSFB_1_internal_pwm_KillModeMinTime) */

/* [] END OF FILE */
